# File: FloridaLakes.s
# Purpose: Estimation for Florida Small Lakes
# Programmer: Tom Kincaid
# Date: October 29, 2006


# Load the psurvey.analysis library

library(psurvey.analysis)

# Read the data file

FLlakedata <- read.table("FLlakedata.tab", header=T, row.names=NULL, sep="\t")
cat("The initial six lines in the data file follow:\n\n")
print(FLlakedata[1:6,])

# Print a table displaying the count for each code for SiteStatus - site
#    evaluation status

cat("\nA table displaying the number of values for each level of the site status variable follows:\n")
# The meaning for each code follows:
#    TS - site was target and sampled
#    TNS - site was target and not sampled
#    NT - site was non-target
#    NN - site was not needed (not evaluated)
print(table(FLlakedata$SiteStatus))


# Conduct an analysis of site evaluation categories

# Create the sites data frame, which identifies sites to use in the analysis
# Note that all sites will be used to estimate stream length in each category

sites <- data.frame(siteID=FLlakedata$FL.SITEID,
                    Use=I(rep(TRUE, nrow(FLlakedata))))

# Create the subpop data frame, which defines populations and subpopulations for
#    which estimates are desired
# Note that the only population is all Florida small lakes

subpop <- data.frame(siteID=FLlakedata$FL.SITEID,
                     Florida=FLlakedata$RESOURCE.TYPE)

# Create the design data frame, which identifies the stratum code, weight,
#    x-coordinate, and y-coordinate for each site ID

design <- data.frame(siteID=FLlakedata$FL.SITEID,
                     stratum=FLlakedata$STRATUM,
                     wgt=FLlakedata$final.wt,
                     xcoord=FLlakedata$xmarinus,
                     ycoord=FLlakedata$ymarinus)

# Create the data.cat data frame, which specifies the variables to use in the
#    analysis

data.cat <- data.frame(siteID=FLlakedata$FL.SITEID,
                       SiteStatus=FLlakedata$SiteStatus)

# Produce estimates for the site evaluation variable
# Note that argument popsize was set equal to the known length of the frame for 
#    Florida small lakes

SiteStatusSum <- cat.analysis(sites, subpop, design, data.cat,
                              popsize=list(Florida=3399))
				         
# Write results as a comma-separated value (csv) file to read into a spreadsheet

write.table(SiteStatusSum, file="SiteStatusSum.csv", sep=",", dimnames.write="colnames")


# Conduct an analysis of fecal coliform categories and pH categories

# Create the sites data frame
# Note that only Target (TS) sites are used

sites <- data.frame(siteID=FLlakedata$FL.SITEID,
                    Use=I(FLlakedata$SiteStatus == "TS"))

# Note that the existing subpop and design data frames can be used

# Create the data.cat data frame

data.cat <- data.frame(siteID=FLlakedata$FL.SITEID,
                       ColiformCat=FLlakedata$Coloform.Cat,
                       pHCat=FLlakedata$pH.Cat)
						
# Produce estimates for fecal coliform categories and pH categories
# Note that the size of the target stream length is not known, so argument
#    popsize is not specified

ConditionSum <- cat.analysis(sites, subpop, design, data.cat)

# Write results as a csv file to read into a spreadsheet

write.table(ConditionSum, file="ConditionSum.csv", sep=",", dimnames.write="colnames")


# Conduct an analysis of turbidity and color

# Note that the existing sites, subpop, and design data frames can be used

# Create the data.cont data frame

data.cont <- data.frame(siteID=FLlakedata$FL.SITEID,
                        Turbidity=FLlakedata$Turbidity,
                        Color=FLlakedata$Color)
				
# Produce estimates for turbidity and color

ScoresSum <- cont.analysis(sites, subpop, design, data.cont)

# Write results as csv files to read in spreadsheets

write.table(ScoresSum$CDF, file="ScoresSumCDF.csv", sep=",", dimnames.write="colnames")
write.table(ScoresSum$Pct, file="ScoresSumPct.csv", sep=",", dimnames.write="colnames")
